# Focus Brief (codex)

## Launch
`codex exec .ai/sessions/20260215T173031+0900_codex_V1.1.prompt.txt`

## Prompt File
`.ai/sessions/20260215T173031+0900_codex_V1.1.prompt.txt`

## Goal
- id: `V1.1`
- title: Improve dry-run mode
- phase: `legacy`
- uncertainty: `unknown`
- allowed changes:
  - `src/hast/core/auto.py`
- test files:
  - `tests/test_auto.py`
